OfflinePushInfo class

Constructors

OfflinePushInfo({String? title, String? desc, bool? disablePush, String? iOSSound, bool? ignoreIOSBadge, String? androidOPPOChannelID, String? ext, String? androidSound, int? androidVIVOClassification, String? androidFCMChannelID, String? androidXiaoMiChannelID, int? iOSPushType, String? androidHuaWeiCategory, String? androidVIVOCategory})
OfflinePushInfo.fromJson(Map<String, dynamic> json)

Properties

androidFCMChannelID ↔ String?
getter/setter pair
androidHuaWeiCategory ↔ String?
getter/setter pair
androidOPPOChannelID ↔ String?
getter/setter pair
androidSound ↔ String?
getter/setter pair
androidVIVOCategory ↔ String?
getter/setter pair
androidVIVOClassification ↔ int?
getter/setter pair
androidXiaoMiChannelID ↔ String?
getter/setter pair
desc ↔ String?
getter/setter pair
disablePush ↔ bool?
getter/setter pair
ext ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoreIOSBadge ↔ bool?
getter/setter pair
iOSPushType ↔ int?
getter/setter pair
iOSSound ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited